pub struct SettlementPolicy {
pub min_settlement_amount: u64,
pub settlement_frequency_hours: u32,
pub auto_settle: bool,
}Fields
min_settlement_amount: u64settlement_frequency_hours: u32auto_settle: boolTrait Implementations
Sourceimpl BorshDeserialize for SettlementPolicy
impl BorshDeserialize for SettlementPolicy
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SettlementPolicy
impl BorshSerialize for SettlementPolicy
Sourceimpl Clone for SettlementPolicy
impl Clone for SettlementPolicy
Sourcefn clone(&self) -> SettlementPolicy
fn clone(&self) -> SettlementPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SettlementPolicy
impl Debug for SettlementPolicy
impl Eq for SettlementPolicy
Sourceimpl PartialEq for SettlementPolicy
impl PartialEq for SettlementPolicy
impl StructuralPartialEq for SettlementPolicy